@@ -13,6 +13,12 @@ ddi <- di(dd, c("var1", "var2", "var3"))
 ## ------------------------------------------------------------------------
 ddi <- di(dd, c("var1", "var2", "var3"), rescale = FALSE)
 
+## ------------------------------------------------------------------------
+ddi <- di(dd, c("var1", "var2", "var3"), rescale.custom = c("var1:0.2:0.8", "var3:0.3:0.7"))
+
+## ------------------------------------------------------------------------
+ddi <- di(dd, c("var1", "var2", "var3"), rescale.avoid = c("var2"))
+
 ## ------------------------------------------------------------------------
 ddi <- di(dd, c("var1", "var2", "var3"), rescale = FALSE, invert=c("var1", "var3"))
 
